aboutsummaryrefslogtreecommitdiff
path: root/format/packfile/header.go
diff options
context:
space:
mode:
authorGravatar Runxi Yu2026-03-29 11:05:46 +0000
committerGravatar Runxi Yu2026-03-29 11:05:46 +0000
commit0109f0903d8e18d110d6b9456f9a1fb4501e62fc (patch)
treef1b95c7c64d79fa0dab0251661600a299d8aefcb /format/packfile/header.go
parentobject{,/type}: Fix up API shape (diff)
signatureNo signature
object/type, format/packfile: API cleanups
Diffstat (limited to 'format/packfile/header.go')
-rw-r--r--format/packfile/header.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/format/packfile/header.go b/format/packfile/header.go
index bc859a55..5f4e4508 100644
--- a/format/packfile/header.go
+++ b/format/packfile/header.go
@@ -3,7 +3,7 @@ package packfile
// Signature is the 4-byte "PACK" magic at the start of pack files.
const Signature = 0x5041434b
-// VersionSupported reports whether one pack version is supported.
-func VersionSupported(version uint32) bool {
+// SupportedVersion reports whether one pack version is supported.
+func SupportedVersion(version uint32) bool {
return version == 2 || version == 3
}